@@ -1,3 +1,4 @@
+# 2010-04-25 CJS fixed problems of init.logitP=+infinity if n1=m2=k which crapped out the lm() call
 # 2010-03-11 Added fixed values of logitP[j] to be provided by user.
 # 2010-03-02 SJB Created file.
 
@@ -316,6 +317,7 @@ if( any(is.na(u2))) {parameters <- c(parameters,"u2")}
                  
 init.vals <- function(){
    init.logitP <- c(logit((apply(m2[,1:(Delta.max+1)],1,sum)+1)/(n1+1)),rep(mu_xiP,Nstrata.cap-Nstrata.rel))         # initial capture rates based on observed recaptures
+   init.logitP <- pmin(10,pmax(-10,init.logitP))
    init.logitP[is.na(init.logitP)] <- -2         # those cases where initial probability is unknown
    init.logitP[!is.na(logitP.fixed)] <- NA        # no need to initialize the fixed values
    
